@@ -1,4 +1,4 @@
-#define NGX_CONFIGURE " --with-cc=x86_64-pc-linux-gnu-gcc --with-cpp='x86_64-pc-linux-gnu-gcc -E' --with-ld-opt='-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs' --builddir=build --prefix=/usr/lib64/nginx --sbin-path=/usr/sbin/nginx --modules-path=/usr/lib64/nginx/modules --conf-path=/etc/nginx/nginx.conf --error-log-path=/var/log/nginx/error.log --http-log-path=/var/log/nginx/access.log --pid-path=/run/nginx/nginx.pid --lock-path=/run/lock/nginx.lock --user=nginx --group=nginx --with-threads --with-compat --http-client-body-temp-path=/var/cache/nginx/client_body_temp --http-proxy-temp-path=/var/cache/nginx/proxy_temp --http-fastcgi-temp-path=/var/cache/nginx/fastcgi_temp --http-uwsgi-temp-path=/var/cache/nginx/uwsgi_temp --http-scgi-temp-path=/var/cache/nginx/scgi_temp --with-http_ssl_module --with-http_v2_module --with-http_v3_module --with-http_realip_module --with-http_gzip_static_module --with-mail_ssl_module --with-stream_ssl_module --with-stream_realip_module"
+#define NGX_CONFIGURE " --with-cc=aarch64-unknown-linux-gnu-gcc --with-cpp='aarch64-unknown-linux-gnu-gcc -E' --with-ld-opt='-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs' --builddir=build --prefix=/usr/lib64/nginx --sbin-path=/usr/sbin/nginx --modules-path=/usr/lib64/nginx/modules --conf-path=/etc/nginx/nginx.conf --error-log-path=/var/log/nginx/error.log --http-log-path=/var/log/nginx/access.log --pid-path=/run/nginx/nginx.pid --lock-path=/run/lock/nginx.lock --user=nginx --group=nginx --with-threads --with-compat --http-client-body-temp-path=/var/cache/nginx/client_body_temp --http-proxy-temp-path=/var/cache/nginx/proxy_temp --http-fastcgi-temp-path=/var/cache/nginx/fastcgi_temp --http-uwsgi-temp-path=/var/cache/nginx/uwsgi_temp --http-scgi-temp-path=/var/cache/nginx/scgi_temp --with-http_ssl_module --with-mail_ssl_module --with-stream_ssl_module"
 
 #ifndef NGX_HAVE_GCC_ATOMIC
 #define NGX_HAVE_GCC_ATOMIC  1
@@ -100,8 +100,8 @@
 #endif
 
 
-#ifndef NGX_HAVE_NONALIGNED
-#define NGX_HAVE_NONALIGNED  1
+#ifndef NGX_ALIGNMENT
+#define NGX_ALIGNMENT  16
 #endif
 
 
@@ -405,36 +405,11 @@
 #endif
 
 
-#ifndef NGX_HTTP_V2
-#define NGX_HTTP_V2  1
-#endif
-
-
-#ifndef NGX_HTTP_V3
-#define NGX_HTTP_V3  1
-#endif
-
-
-#ifndef NGX_HTTP_GZIP
-#define NGX_HTTP_GZIP  1
-#endif
-
-
 #ifndef NGX_CRYPT
 #define NGX_CRYPT  1
 #endif
 
 
-#ifndef NGX_HTTP_REALIP
-#define NGX_HTTP_REALIP  1
-#endif
-
-
-#ifndef NGX_HTTP_X_FORWARDED_FOR
-#define NGX_HTTP_X_FORWARDED_FOR  1
-#endif
-
-
 #ifndef NGX_HTTP_X_FORWARDED_FOR
 #define NGX_HTTP_X_FORWARDED_FOR  1
 #endif
@@ -455,11 +430,6 @@
 #endif
 
 
-#ifndef NGX_QUIC_BPF
-#define NGX_QUIC_BPF  1
-#endif
-
-
 #ifndef NGX_COMPAT
 #define NGX_COMPAT  1
 #endif
@@ -520,11 +490,6 @@
 #endif
 
 
-#ifndef NGX_QUIC
-#define NGX_QUIC  1
-#endif
-
-
 #ifndef NGX_ZLIB
 #define NGX_ZLIB  1
 #endif
